CustomRb class

A custom radio button widget that extends StatelessWidget.

Inheritance

Constructors

CustomRb({Key? key, double spacing = 5, required Widget child, TextDirection textDirection = TextDirection.ltr, required bool value, CheckboxStyle style = const CheckboxStyle(), void onChanged(bool value)?})
const

Properties

child Widget
The label beside the marker.
final
hashCode int
The hash code for this object.
no setterinherited
key Key?
Controls how one widget replaces another widget in the tree.
finalinherited
onChanged → void Function(bool value)?
Called when the marker is tapped, if CheckboxStyle.interactive is set.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
spacing double
Space either side of the marker.
final
style CheckboxStyle
Resolved appearance. Null fields keep the Material defaults.
final
textDirection TextDirection
Text direction of the row.
final
value bool
Whether this option is selected.
final

Methods

build(BuildContext context) Widget
Describes the part of the user interface represented by this widget.
override
createElement() StatelessElement
Creates a StatelessElement to manage this widget's location in the tree.
inherited
debugDescribeChildren() List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) String
Returns a one-line detailed description of the object.
inherited
toStringShort() String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited