maxLines property

int? get maxLines
inherited

An optional maximum number of lines for the text to span, wrapping if necessary. If the text exceeds the given number of lines, it will be truncated according to overflow and softWrap.

Implementation

int? get maxLines => _textPainter.maxLines;
set maxLines (int? value)
inherited

The value may be null. If it is not null, then it must be greater than zero.

Implementation

set maxLines(int? value) {
  assert(value == null || value > 0);
  if (_textPainter.maxLines == value) {
    return;
  }
  _textPainter.maxLines = value;
  _overflowShader = null;
  markNeedsLayout();
}