softWrap property

bool get softWrap
inherited

Whether the text should break at soft line breaks.

If false, the glyphs in the text will be positioned as if there was unlimited horizontal space.

If softWrap is false, overflow and textAlign may have unexpected effects.

Implementation

bool get softWrap => _softWrap;
set softWrap (bool value)
inherited

Implementation

set softWrap(bool value) {
  if (_softWrap == value) {
    return;
  }
  _softWrap = value;
  markNeedsLayout();
}