InlineCodeRun class

A resolved inline-code run: a range of the paragraph's plain text, and the style its chip is drawn with.

Annotations

Constructors

InlineCodeRun({required int start, required int end, required InlineCodeStyle style})
Creates an inline-code run.
const

Properties

end int
One past the last code unit of the run.
final
hashCode int
The hash code for this object.
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
start int
First code unit of the run, in the paragraph's plain text.
final
style InlineCodeStyle
The resolved style for this run.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override