fontFamily property
The monospace family. Defaults to the bundled JetBrains Mono, the same family fenced code blocks use.
Implementation
final String? fontFamily;
The monospace family. Defaults to the bundled JetBrains Mono, the same family fenced code blocks use.
final String? fontFamily;