inlineDirectives property
Host-defined inline regions the parser must not look inside.
See InlineDirective.
Implementation
final List<InlineDirective>? inlineDirectives;
Host-defined inline regions the parser must not look inside.
See InlineDirective.
final List<InlineDirective>? inlineDirectives;