HighlightBuilder typedef

  1. @Deprecated('Use InlineCodeBuilder via GptMarkdown.inlineCodeBuilder. ' 'This returns a Widget, which the package has to wrap in a WidgetSpan: it ' 'sits off the baseline, cannot wrap across lines, is skipped by text ' 'selection, and does not paint on iOS inside a link label. ' 'Will be removed in 2.0.0.')
HighlightBuilder = Widget Function(BuildContext context, String text, TextStyle style)

A builder function for the highlight.

Implementation

@Deprecated(
  'Use InlineCodeBuilder via GptMarkdown.inlineCodeBuilder. '
  'This returns a Widget, which the package has to wrap in a WidgetSpan: it '
  'sits off the baseline, cannot wrap across lines, is skipped by text '
  'selection, and does not paint on iOS inside a link label. '
  'Will be removed in 2.0.0.',
)
typedef HighlightBuilder =
    Widget Function(BuildContext context, String text, TextStyle style);