BoldMd class
Bold text component
- Inheritance
-
- Object
- MarkdownComponent
- InlineMd
- BoldMd
Constructors
- BoldMd()
Properties
- exp → RegExp
-
no setteroverride
- hashCode → int
-
The hash code for this object.
no setterinherited
- inline → bool
-
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
scopes
→ Set<
MarkdownScope> -
The nesting contexts this component is allowed to render in.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
span(
BuildContext context, String text, GptMarkdownConfig config) → InlineSpan -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited