GptMarkdown class

This widget create a full markdown widget as a column view.

Inheritance

Constructors

GptMarkdown(String data, {Key? key, TextStyle? style, bool followLinkColor = false, TextDirection textDirection = TextDirection.ltr, String latexWorkaround(String tex)?, TextAlign? textAlign, ImageBuilder? imageBuilder, TextScaler? textScaler, void onLinkTap(String url, String title)?, LatexBuilder? latexBuilder, CodeBlockBuilder? codeBuilder, SourceTagBuilder? sourceTagBuilder, HighlightBuilder? highlightBuilder, LinkBuilder? linkBuilder, int? maxLines, TextOverflow? overflow, OrderedListBuilder? orderedListBuilder, UnOrderedListBuilder? unOrderedListBuilder, TableBuilder? tableBuilder, List<MarkdownComponent>? components, List<MarkdownComponent>? inlineComponents, bool useDollarSignsForLatex = false})
const

Properties

codeBuilder CodeBlockBuilder?
The code builder.
final
components List<MarkdownComponent>?
The list of components.
final
data String
The data to be displayed.
final
followLinkColor bool
Whether to follow the link color.
final
hashCode int
The hash code for this object.
no setterinherited
highlightBuilder HighlightBuilder?
The highlight builder.
final
imageBuilder ImageBuilder?
The image builder.
final
inlineComponents List<MarkdownComponent>?
The list of inline components.
final
key Key?
Controls how one widget replaces another widget in the tree.
finalinherited
latexBuilder LatexBuilder?
The LaTeX builder.
final
latexWorkaround String Function(String tex)?
The LaTeX workaround.
final
linkBuilder LinkBuilder?
The link builder.
final
maxLines int?
final
onLinkTap → void Function(String url, String title)?
The callback function to handle link clicks.
final
orderedListBuilder OrderedListBuilder?
The ordered list builder.
final
overflow TextOverflow?
The overflow.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
sourceTagBuilder HighlightBuilder?
The source tag builder.
final
style TextStyle?
The style of the text.
final
tableBuilder TableBuilder?
The table builder.
final
textAlign TextAlign?
The alignment of the text.
final
textDirection TextDirection
The direction of the text.
final
textScaler TextScaler?
The text scaler.
final
unOrderedListBuilder UnOrderedListBuilder?
The unordered list builder.
final
useDollarSignsForLatex bool
Whether to use dollar signs for LaTeX.
final

Methods

build(BuildContext context) Widget
A method to remove extra lines inside block LaTeX.
override
createElement() StatelessElement
Creates a StatelessElement to manage this widget's location in the tree.
inherited
debugDescribeChildren() List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) String
Returns a one-line detailed description of the object.
inherited
toStringShort() String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited