MarkdownComponent class abstract
Markdown components
Constructors
Properties
- exp → RegExp
-
no setter
- hashCode → int
-
The hash code for this object.
no setterinherited
- inline → bool
-
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
scopes
→ Set<
MarkdownScope> -
The nesting contexts this component is allowed to render in.
no setter
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
span(
BuildContext context, String text, GptMarkdownConfig config) → InlineSpan -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Properties
-
globalComponents
→ List<
MarkdownComponent> -
no setter
-
inlineComponents
→ List<
MarkdownComponent> -
final
Static Methods
-
generate(
BuildContext context, String text, GptMarkdownConfig config, bool includeGlobalComponents) → List< InlineSpan> - Generate widget for markdown widget
Constants
-
allScopes
→ const Set<
MarkdownScope> - Every scope — the default value of scopes.
-
allScopesExceptLinkLabel
→ const Set<
MarkdownScope> - Every scope except MarkdownScope.linkLabel.