MdCustomBlock class

An extension's parsed payload. body remains raw unless the extension explicitly parses it; data should be immutable and independent of Flutter.

Inheritance

Constructors

MdCustomBlock({required String type, required String body, Object? data, bool closed = true})
const

Properties

body String
final
closed bool
final
data Object?
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
type String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited