MdImage class
Constructors
Properties
- alt → String
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- height → double?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- url → String
-
final
- width → double?
-
Width parsed from an alt of the form
WxH(e.g.).final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited