MdOrderedList class

Inheritance

Constructors

MdOrderedList({required int start, required List<MdListItem> items})
const

Properties

hashCode int
The hash code for this object.
no setterinherited
items List<MdListItem>
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
start int
The first ordered number (e.g. 3 for a list starting 3.).
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited