MdTable class

Inheritance

Constructors

MdTable({required List<MdAlign> aligns, required MdTableRow header, required List<MdTableRow> rows})
const

Properties

aligns List<MdAlign>
final
hashCode int
The hash code for this object.
no setterinherited
final
rows List<MdTableRow>
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited