truncateTo method
Clamps the reveal when the source shrank to a prefix of itself.
Implementation
void truncateTo(int length) {
if (_revealed > length) {
_revealed = length.toDouble();
}
}
Clamps the reveal when the source shrank to a prefix of itself.
void truncateTo(int length) {
if (_revealed > length) {
_revealed = length.toDouble();
}
}