streaming/stream_split library

Finding a safe place to cut streaming Markdown in two.

Functions

settledSplitOffset(String source) int
The offset of the last blank line that is safe to split at, or 0 when the whole document has to stay together.