builder property
Renders a slice of the source. The same builder is used for the settled prefix and the live tail.
Implementation
final StreamingMarkdownBuilder builder;
Renders a slice of the source. The same builder is used for the settled prefix and the live tail.
final StreamingMarkdownBuilder builder;