charactersPerSecond property

double charactersPerSecond
final

Baseline reveal speed. The reveal goes faster than this on its own whenever it would otherwise fall behind the incoming text.

Implementation

final double charactersPerSecond;