textStyle property
Applied on top of the surrounding text style for the body. Defaults to no change.
Implementation
final TextStyle? textStyle;
Applied on top of the surrounding text style for the body. Defaults to no change.
final TextStyle? textStyle;