gapAfterMarker property
Space between marker and text. Defaults to the value each list kind already used — 10 for bullets, 6 for numbers.
Implementation
final double? gapAfterMarker;
Space between marker and text. Defaults to the value each list kind already used — 10 for bullets, 6 for numbers.
final double? gapAfterMarker;