indent property
Space before the marker. Defaults to the value each list kind already used — 7 for bullets, 6 for numbers.
Implementation
final double? indent;
Space before the marker. Defaults to the value each list kind already used — 7 for bullets, 6 for numbers.
final double? indent;