InlineTapRun class
A resolved tap target: a range of the paragraph's plain text, and what to run when it is hit.
- Annotations
Constructors
- InlineTapRun({required int start, required int end, VoidCallback? onTap, TextStyle? hoverStyle})
-
Creates a tap run.
const
Properties
- end → int
-
One past the last code unit of the run.
final
- hashCode → int
-
The hash code for this object.
no setteroverride
- hoverStyle → TextStyle?
-
Applied while the pointer is inside the run.
final
- onTap → VoidCallback?
-
Run on tap.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- start → int
-
First code unit of the run, in the paragraph's plain text.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override