LinkButton class
A custom button widget that displays a link with customisable colours.
- Inheritance
-
- Object
- DiagnosticableTree
- Widget
- StatefulWidget
- LinkButton
Constructors
- LinkButton({Key? key, required String text, required GptMarkdownConfig config, required Color color, required Color hoverColor, VoidCallback? onPressed, TextStyle? textStyle, String? url, Widget? child, LinkSpanBuilder? spanBuilder})
-
const
Properties
- child → Widget?
-
A pre-built child widget (used by
linkBuildercustom rendering).final - color → Color
-
The colour used for the link in its default (non-hover) state.
final
- config → GptMarkdownConfig
-
The configuration for the link.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- hoverColor → Color
-
The colour used for the link when the cursor is hovering over it.
final
- key → Key?
-
Controls how one widget replaces another widget in the tree.
finalinherited
- onPressed → VoidCallback?
-
The callback function to be called when the link is pressed.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- spanBuilder → LinkSpanBuilder?
-
Builds a colour-aware InlineSpan for the link text.
final
- text → String
-
The raw link text (used only as fallback when neither child nor
spanBuilder is provided).
final
- textStyle → TextStyle?
-
The style of the text.
final
- url → String?
-
The URL of the link.
final
Methods
-
createElement(
) → StatefulElement -
Creates a StatefulElement to manage this widget's location in the tree.
inherited
-
createState(
) → State< LinkButton> -
Creates the mutable state for this widget at a given location in the tree.
override
-
debugDescribeChildren(
) → List< DiagnosticsNode> -
Returns a list of DiagnosticsNode objects describing this node's
children.
inherited
-
debugFillProperties(
DiagnosticPropertiesBuilder properties) → void -
Add additional properties associated with the node.
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toDiagnosticsNode(
{String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode -
Returns a debug representation of the object that is used by debugging
tools and by DiagnosticsNode.toStringDeep.
inherited
-
toString(
{DiagnosticLevel minLevel = DiagnosticLevel.info}) → String -
A string representation of this object.
inherited
-
toStringDeep(
{String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String -
Returns a string representation of this node and its descendants.
inherited
-
toStringShallow(
{String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String -
Returns a one-line detailed description of the object.
inherited
-
toStringShort(
) → String -
A short, textual description of this widget.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited