FencedBlockSyntax class
A convenient opaque container such as :::warning ... :::. Its body is
raw text, including blank lines. An unfinished block consumes the remaining
input with MdCustomBlock.closed false. It does not nest the same fence.
- Inheritance
-
- Object
- MarkdownBlockSyntax
- FencedBlockSyntax
Constructors
- FencedBlockSyntax({required String type, required String opening, String closing = ':::'})
-
const
Properties
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
parse(
List< String> lines, int startLine) → MarkdownBlockMatch? -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited