charactersPerSecond property
Baseline reveal speed. The reveal goes faster than this on its own whenever it would otherwise fall behind the incoming text.
Implementation
final double charactersPerSecond;
Baseline reveal speed. The reveal goes faster than this on its own whenever it would otherwise fall behind the incoming text.
final double charactersPerSecond;